Module plugin_invoker

Module plugin_invoker 

Plugin invocation and execution

Structs

ArtifactBundle
A directory-backed plugin artifact with one JSON entrypoint.
PluginArtifactInvocationResult
Result of artifact-mode plugin invocation.
PluginInvocationOptions
Options that control one plugin invocation.
PluginInvocationResult
Result of running a plugin through the Python bridge.
PluginInvocationTimings
Timings for a plugin invocation phase

Enums

ArtifactOutputKind
Type of data produced by an artifact-mode plugin invocation.
PluginInput
Direct input supplied to a plugin invocation.
PluginInvocationOutput
Materialized result of running a plugin through the Python bridge.