pub enum PluginInvocationOutput {
Json(String),
Persisted,
Empty,
}Expand description
Materialized result of running a plugin through the Python bridge.
Variants
Json(String)
JSON text that should be emitted or written by the caller.
Persisted
A System was written directly to the requested output path.
Empty
The plugin intentionally produced no stream output.