pub struct Bridge { /* private fields */ }Expand description
The Python bridge for plugin execution
Implementations
Sourceimpl Bridge
impl Bridge
Sourcepub fn invoke_plugin_direct(
&self,
target: &str,
config_json: &str,
input: Option<PluginInput<'_>>,
output_path: Option<&Path>,
plugin_metadata: Option<&Plugin>,
options: PluginInvocationOptions,
) -> Result<PluginInvocationResult, BridgeError>
pub fn invoke_plugin_direct( &self, target: &str, config_json: &str, input: Option<PluginInput<'_>>, output_path: Option<&Path>, plugin_metadata: Option<&Plugin>, options: PluginInvocationOptions, ) -> Result<PluginInvocationResult, BridgeError>
Invoke a plugin through the direct CLI interface.
Direct invocations treat an unused stream input as an error, redirect plugin writes away from stdout, and can persist System results directly to a durable JSON entrypoint.
pub fn invoke_plugin_with_bindings( &self, target: &str, config_json: &str, stdin_json: Option<&str>, runtime_bindings: Option<&RuntimeBindings>, options: PluginInvocationOptions, ) -> Result<PluginInvocationResult, BridgeError>
Sourcepub fn save_system_artifact_as_zip(
&self,
input: &ArtifactBundle,
output: &Path,
) -> Result<(), BridgeError>
pub fn save_system_artifact_as_zip( &self, input: &ArtifactBundle, output: &Path, ) -> Result<(), BridgeError>
Save a System artifact as an infrasys ZIP archive.
Sourcepub fn invoke_plugin_with_artifact_bindings(
&self,
target: &str,
config_json: &str,
input: Option<&ArtifactBundle>,
output: &ArtifactBundle,
runtime_bindings: Option<&RuntimeBindings>,
options: PluginInvocationOptions,
) -> Result<PluginArtifactInvocationResult, BridgeError>
pub fn invoke_plugin_with_artifact_bindings( &self, target: &str, config_json: &str, input: Option<&ArtifactBundle>, output: &ArtifactBundle, runtime_bindings: Option<&RuntimeBindings>, options: PluginInvocationOptions, ) -> Result<PluginArtifactInvocationResult, BridgeError>
Artifact-mode counterpart of Self::invoke_plugin_with_bindings.